# Setup
Synthegrator needs to be able to access the DyPyBench data
on the host. You can download this by pulling the docker 
container and then pullout out the code
```bash
mkdir -p dypybench_projects && docker run -v "$(pwd)/dypybench_projects:/projectmnt" dypybench/dypybench:v1.0 /bin/sh -c "cp -r /Project/* /projectmnt/"
```

# Setting Environment Variables
When running scripts that use DyPyBench you should set
your DYPYBENCH_PROJECTS_ROOT environment variable to this directory.